@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010 Robert Ancell.
+ * Copyright (C) 2010-2011 Robert Ancell.
  * Author: Robert Ancell <robert.ancell@canonical.com>
  * 
  * This program is free software: you can redistribute it and/or modify it under
@@ -15,6 +15,8 @@
 #include <glib-object.h>
 #include <gio/gio.h>
 
+#include "xauthority.h"
+
 G_BEGIN_DECLS
 
 #define XDMCP_SESSION_TYPE (xdmcp_session_get_type())
@@ -41,15 +43,9 @@ guint16 xdmcp_session_get_id (XDMCPSession *session);
 
 const gchar *xdmcp_session_get_manufacturer_display_id (XDMCPSession *session);
 
-const GInetAddress *xdmcp_session_get_address (XDMCPSession *session);
+GInetAddress *xdmcp_session_get_address (XDMCPSession *session);
 
-const GInetAddress *xdmcp_session_get_address6 (XDMCPSession *session);
-
-const gchar *xdmcp_session_get_authorization_name (XDMCPSession *session);
-
-const guchar *xdmcp_session_get_authorization_data (XDMCPSession *session);
-
-const gsize xdmcp_session_get_authorization_data_length (XDMCPSession *session);
+XAuthority *xdmcp_session_get_authority (XDMCPSession *session);
 
 guint16 xdmcp_session_get_display_number (XDMCPSession *session);
 
