@@ -118,21 +118,12 @@ setuid (uid_t uid)
 }
 
 #ifdef __linux__
-int
-open (const char *pathname, int flags, ...)
+static int
+open_wrapper (const char *func, const char *pathname, int flags, mode_t mode)
 {
     int (*_open) (const char * pathname, int flags, mode_t mode);
-    int mode = 0;
-  
-    if (flags & O_CREAT)
-    {
-        va_list ap;
-        va_start (ap, flags);
-        mode = va_arg (ap, int);
-        va_end (ap);
-    }
 
-    _open = (int (*)(const char * pathname, int flags, mode_t mode)) dlsym (RTLD_NEXT, "open");
+    _open = (int (*)(const char * pathname, int flags, mode_t mode)) dlsym (RTLD_NEXT, func);
     if (strcmp (pathname, "/dev/console") == 0)
     {
         if (console_fd < 0)
@@ -157,6 +148,34 @@ open (const char *pathname, int flags, ...)
         return _open (pathname, flags, mode);
 }
 
+int
+open (const char *pathname, int flags, ...)
+{
+    int mode = 0;
+    if (flags & O_CREAT)
+    {
+        va_list ap;
+        va_start (ap, flags);
+        mode = va_arg (ap, int);
+        va_end (ap);
+    }
+    return open_wrapper ("open", pathname, flags, mode);
+}
+
+int
+open64 (const char *pathname, int flags, ...)
+{
+    int mode = 0;
+    if (flags & O_CREAT)
+    {
+        va_list ap;
+        va_start (ap, flags);
+        mode = va_arg (ap, int);
+        va_end (ap);
+    }
+    return open_wrapper ("open64", pathname, flags, mode);
+}
+
 int
 ioctl (int d, int request, void *data)
 {
@@ -547,6 +566,13 @@ pam_authenticate (pam_handle_t *pamh, int flags)
             msg[n_messages]->msg = "You should have seen three messages";
             n_messages++;
         }
+        if (strcmp (pamh->user, "multi-prompt") == 0)
+        {
+            msg[n_messages] = malloc (sizeof (struct pam_message));
+            msg[n_messages]->msg_style = PAM_PROMPT_ECHO_ON;
+            msg[n_messages]->msg = "Favorite Color:";
+            n_messages++;
+        }
         msg[n_messages] = malloc (sizeof (struct pam_message));
         msg[n_messages]->msg_style = PAM_PROMPT_ECHO_OFF;
         msg[n_messages]->msg = "Password:";
@@ -569,6 +595,10 @@ pam_authenticate (pam_handle_t *pamh, int flags)
 
         if (entry)
             password_matches = strcmp (entry->pw_passwd, resp[password_index].resp) == 0;
+
+        if (password_matches && strcmp (pamh->user, "multi-prompt") == 0)
+            password_matches = strcmp ("blue", resp[0].resp) == 0;
+
         for (i = 0; i < n_messages; i++)
         {
             if (resp[i].resp)
